@@ -88,6 +88,10 @@ class DataFieldRow extends RowPluginBase {
 
     if ($fields = $this->view->display_handler->getOption('fields')) {
       foreach ($fields as $id => $field) {
+        // Don't show the field if it has been excluded.
+        if (!empty($field['exclude'])) {
+          continue;
+        }
         $form['field_options'][$id]['field'] = array(
           '#markup' => $id,
         );
@@ -138,6 +142,10 @@ class DataFieldRow extends RowPluginBase {
     $output = array();
 
     foreach ($this->view->field as $id => $field) {
+      // Don't render anything if this field is excluded.
+      if (!empty($field->options['exclude'])) {
+        continue;
+      }
       // If the raw output option has been set, just get the raw value.
       if (!empty($this->rawOutputOptions[$id])) {
         $value = $field->getValue($row);
