@@ -9,9 +9,9 @@
 namespace {
 
 /**
- * CssRenderer uses file_create_url(), which *is* available when using the
- * Simpletest test runner, but not when using the PHPUnit test runner; hence
- * this hack.
+ * CssCollectionRenderer uses file_create_url() & file_url_transform_relative(),
+ * which *are* available when using the Simpletest test runner, but not when
+ * using the PHPUnit test runner; hence this hack.
  */
 if (!function_exists('file_create_url')) {
 
@@ -23,6 +23,17 @@ if (!function_exists('file_create_url')) {
     return 'file_create_url:' . $uri;
   }
 
+}
+if (!function_exists('file_url_transform_relative')) {
+
+  /**
+   * Temporary mock of file_url_transform_relative, until that is moved into
+   * Component/Utility.
+   */
+  function file_url_transform_relative($uri) {
+    return 'file_url_transform_relative:' . $uri;
+  }
+
 }
 
 }
@@ -153,7 +164,7 @@ class CssCollectionRendererUnitTest extends UnitTestCase {
           0 => array('group' => 0, 'type' => 'file', 'media' => 'all', 'preprocess' => TRUE, 'data' => 'public://css/file-all', 'browsers' => array()),
         ),
         array(
-          0 => $create_link_element(file_create_url('public://css/file-all') . '?0', 'all'),
+          0 => $create_link_element(file_url_transform_relative(file_create_url('public://css/file-all')) . '?0', 'all'),
         ),
       ),
       // 31 file CSS assets: expect 31 link elements.
@@ -192,37 +203,37 @@ class CssCollectionRendererUnitTest extends UnitTestCase {
           30 => $create_file_css_asset('public://css/31.css'),
         ),
         array(
-          0 => $create_link_element(file_create_url('public://css/1.css') . '?0'),
-          1 => $create_link_element(file_create_url('public://css/2.css') . '?0'),
-          2 => $create_link_element(file_create_url('public://css/3.css') . '?0'),
-          3 => $create_link_element(file_create_url('public://css/4.css') . '?0'),
-          4 => $create_link_element(file_create_url('public://css/5.css') . '?0'),
-          5 => $create_link_element(file_create_url('public://css/6.css') . '?0'),
-          6 => $create_link_element(file_create_url('public://css/7.css') . '?0'),
-          7 => $create_link_element(file_create_url('public://css/8.css') . '?0'),
-          8 => $create_link_element(file_create_url('public://css/9.css') . '?0'),
-          9 => $create_link_element(file_create_url('public://css/10.css') . '?0'),
-          10 => $create_link_element(file_create_url('public://css/11.css') . '?0'),
-          11 => $create_link_element(file_create_url('public://css/12.css') . '?0'),
-          12 => $create_link_element(file_create_url('public://css/13.css') . '?0'),
-          13 => $create_link_element(file_create_url('public://css/14.css') . '?0'),
-          14 => $create_link_element(file_create_url('public://css/15.css') . '?0'),
-          15 => $create_link_element(file_create_url('public://css/16.css') . '?0'),
-          16 => $create_link_element(file_create_url('public://css/17.css') . '?0'),
-          17 => $create_link_element(file_create_url('public://css/18.css') . '?0'),
-          18 => $create_link_element(file_create_url('public://css/19.css') . '?0'),
-          19 => $create_link_element(file_create_url('public://css/20.css') . '?0'),
-          20 => $create_link_element(file_create_url('public://css/21.css') . '?0'),
-          21 => $create_link_element(file_create_url('public://css/22.css') . '?0'),
-          22 => $create_link_element(file_create_url('public://css/23.css') . '?0'),
-          23 => $create_link_element(file_create_url('public://css/24.css') . '?0'),
-          24 => $create_link_element(file_create_url('public://css/25.css') . '?0'),
-          25 => $create_link_element(file_create_url('public://css/26.css') . '?0'),
-          26 => $create_link_element(file_create_url('public://css/27.css') . '?0'),
-          27 => $create_link_element(file_create_url('public://css/28.css') . '?0'),
-          28 => $create_link_element(file_create_url('public://css/29.css') . '?0'),
-          29 => $create_link_element(file_create_url('public://css/30.css') . '?0'),
-          30 => $create_link_element(file_create_url('public://css/31.css') . '?0'),
+          0 => $create_link_element(file_url_transform_relative(file_create_url('public://css/1.css')) . '?0'),
+          1 => $create_link_element(file_url_transform_relative(file_create_url('public://css/2.css')) . '?0'),
+          2 => $create_link_element(file_url_transform_relative(file_create_url('public://css/3.css')) . '?0'),
+          3 => $create_link_element(file_url_transform_relative(file_create_url('public://css/4.css')) . '?0'),
+          4 => $create_link_element(file_url_transform_relative(file_create_url('public://css/5.css')) . '?0'),
+          5 => $create_link_element(file_url_transform_relative(file_create_url('public://css/6.css')) . '?0'),
+          6 => $create_link_element(file_url_transform_relative(file_create_url('public://css/7.css')) . '?0'),
+          7 => $create_link_element(file_url_transform_relative(file_create_url('public://css/8.css')) . '?0'),
+          8 => $create_link_element(file_url_transform_relative(file_create_url('public://css/9.css')) . '?0'),
+          9 => $create_link_element(file_url_transform_relative(file_create_url('public://css/10.css')) . '?0'),
+          10 => $create_link_element(file_url_transform_relative(file_create_url('public://css/11.css')) . '?0'),
+          11 => $create_link_element(file_url_transform_relative(file_create_url('public://css/12.css')) . '?0'),
+          12 => $create_link_element(file_url_transform_relative(file_create_url('public://css/13.css')) . '?0'),
+          13 => $create_link_element(file_url_transform_relative(file_create_url('public://css/14.css')) . '?0'),
+          14 => $create_link_element(file_url_transform_relative(file_create_url('public://css/15.css')) . '?0'),
+          15 => $create_link_element(file_url_transform_relative(file_create_url('public://css/16.css')) . '?0'),
+          16 => $create_link_element(file_url_transform_relative(file_create_url('public://css/17.css')) . '?0'),
+          17 => $create_link_element(file_url_transform_relative(file_create_url('public://css/18.css')) . '?0'),
+          18 => $create_link_element(file_url_transform_relative(file_create_url('public://css/19.css')) . '?0'),
+          19 => $create_link_element(file_url_transform_relative(file_create_url('public://css/20.css')) . '?0'),
+          20 => $create_link_element(file_url_transform_relative(file_create_url('public://css/21.css')) . '?0'),
+          21 => $create_link_element(file_url_transform_relative(file_create_url('public://css/22.css')) . '?0'),
+          22 => $create_link_element(file_url_transform_relative(file_create_url('public://css/23.css')) . '?0'),
+          23 => $create_link_element(file_url_transform_relative(file_create_url('public://css/24.css')) . '?0'),
+          24 => $create_link_element(file_url_transform_relative(file_create_url('public://css/25.css')) . '?0'),
+          25 => $create_link_element(file_url_transform_relative(file_create_url('public://css/26.css')) . '?0'),
+          26 => $create_link_element(file_url_transform_relative(file_create_url('public://css/27.css')) . '?0'),
+          27 => $create_link_element(file_url_transform_relative(file_create_url('public://css/28.css')) . '?0'),
+          28 => $create_link_element(file_url_transform_relative(file_create_url('public://css/29.css')) . '?0'),
+          29 => $create_link_element(file_url_transform_relative(file_create_url('public://css/30.css')) . '?0'),
+          30 => $create_link_element(file_url_transform_relative(file_create_url('public://css/31.css')) . '?0'),
         ),
       ),
       // 32 file CSS assets with the same properties: expect 2 style elements.
@@ -263,40 +274,40 @@ class CssCollectionRendererUnitTest extends UnitTestCase {
         ),
         array(
           0 => $create_style_element('
-@import url("' . file_create_url('public://css/1.css') . '?0");
-@import url("' . file_create_url('public://css/2.css') . '?0");
-@import url("' . file_create_url('public://css/3.css') . '?0");
-@import url("' . file_create_url('public://css/4.css') . '?0");
-@import url("' . file_create_url('public://css/5.css') . '?0");
-@import url("' . file_create_url('public://css/6.css') . '?0");
-@import url("' . file_create_url('public://css/7.css') . '?0");
-@import url("' . file_create_url('public://css/8.css') . '?0");
-@import url("' . file_create_url('public://css/9.css') . '?0");
-@import url("' . file_create_url('public://css/10.css') . '?0");
-@import url("' . file_create_url('public://css/11.css') . '?0");
-@import url("' . file_create_url('public://css/12.css') . '?0");
-@import url("' . file_create_url('public://css/13.css') . '?0");
-@import url("' . file_create_url('public://css/14.css') . '?0");
-@import url("' . file_create_url('public://css/15.css') . '?0");
-@import url("' . file_create_url('public://css/16.css') . '?0");
-@import url("' . file_create_url('public://css/17.css') . '?0");
-@import url("' . file_create_url('public://css/18.css') . '?0");
-@import url("' . file_create_url('public://css/19.css') . '?0");
-@import url("' . file_create_url('public://css/20.css') . '?0");
-@import url("' . file_create_url('public://css/21.css') . '?0");
-@import url("' . file_create_url('public://css/22.css') . '?0");
-@import url("' . file_create_url('public://css/23.css') . '?0");
-@import url("' . file_create_url('public://css/24.css') . '?0");
-@import url("' . file_create_url('public://css/25.css') . '?0");
-@import url("' . file_create_url('public://css/26.css') . '?0");
-@import url("' . file_create_url('public://css/27.css') . '?0");
-@import url("' . file_create_url('public://css/28.css') . '?0");
-@import url("' . file_create_url('public://css/29.css') . '?0");
-@import url("' . file_create_url('public://css/30.css') . '?0");
-@import url("' . file_create_url('public://css/31.css') . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/1.css')) . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/2.css')) . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/3.css')) . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/4.css')) . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/5.css')) . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/6.css')) . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/7.css')) . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/8.css')) . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/9.css')) . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/10.css')) . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/11.css')) . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/12.css')) . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/13.css')) . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/14.css')) . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/15.css')) . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/16.css')) . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/17.css')) . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/18.css')) . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/19.css')) . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/20.css')) . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/21.css')) . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/22.css')) . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/23.css')) . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/24.css')) . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/25.css')) . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/26.css')) . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/27.css')) . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/28.css')) . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/29.css')) . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/30.css')) . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/31.css')) . '?0");
 ', 'all'),
           1 => $create_style_element('
-@import url("' . file_create_url('public://css/32.css') . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/32.css')) . '?0");
 ', 'all'),
         ),
       ),
@@ -340,46 +351,46 @@ class CssCollectionRendererUnitTest extends UnitTestCase {
         ),
         array(
           0 => $create_style_element('
-@import url("' . file_create_url('public://css/1.css') . '?0");
-@import url("' . file_create_url('public://css/2.css') . '?0");
-@import url("' . file_create_url('public://css/3.css') . '?0");
-@import url("' . file_create_url('public://css/4.css') . '?0");
-@import url("' . file_create_url('public://css/5.css') . '?0");
-@import url("' . file_create_url('public://css/6.css') . '?0");
-@import url("' . file_create_url('public://css/7.css') . '?0");
-@import url("' . file_create_url('public://css/8.css') . '?0");
-@import url("' . file_create_url('public://css/9.css') . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/1.css')) . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/2.css')) . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/3.css')) . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/4.css')) . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/5.css')) . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/6.css')) . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/7.css')) . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/8.css')) . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/9.css')) . '?0");
 ', 'all'),
           1 => $create_style_element('
-@import url("' . file_create_url('public://css/10.css') . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/10.css')) . '?0");
 ', 'screen'),
           2 => $create_style_element('
-@import url("' . file_create_url('public://css/11.css') . '?0");
-@import url("' . file_create_url('public://css/12.css') . '?0");
-@import url("' . file_create_url('public://css/13.css') . '?0");
-@import url("' . file_create_url('public://css/14.css') . '?0");
-@import url("' . file_create_url('public://css/15.css') . '?0");
-@import url("' . file_create_url('public://css/16.css') . '?0");
-@import url("' . file_create_url('public://css/17.css') . '?0");
-@import url("' . file_create_url('public://css/18.css') . '?0");
-@import url("' . file_create_url('public://css/19.css') . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/11.css')) . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/12.css')) . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/13.css')) . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/14.css')) . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/15.css')) . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/16.css')) . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/17.css')) . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/18.css')) . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/19.css')) . '?0");
 ', 'all'),
           3 => $create_style_element('
-@import url("' . file_create_url('public://css/20.css') . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/20.css')) . '?0");
 ', 'print'),
           4 => $create_style_element('
-@import url("' . file_create_url('public://css/21.css') . '?0");
-@import url("' . file_create_url('public://css/22.css') . '?0");
-@import url("' . file_create_url('public://css/23.css') . '?0");
-@import url("' . file_create_url('public://css/24.css') . '?0");
-@import url("' . file_create_url('public://css/25.css') . '?0");
-@import url("' . file_create_url('public://css/26.css') . '?0");
-@import url("' . file_create_url('public://css/27.css') . '?0");
-@import url("' . file_create_url('public://css/28.css') . '?0");
-@import url("' . file_create_url('public://css/29.css') . '?0");
-@import url("' . file_create_url('public://css/30.css') . '?0");
-@import url("' . file_create_url('public://css/31.css') . '?0");
-@import url("' . file_create_url('public://css/32.css') . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/21.css')) . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/22.css')) . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/23.css')) . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/24.css')) . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/25.css')) . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/26.css')) . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/27.css')) . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/28.css')) . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/29.css')) . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/30.css')) . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/31.css')) . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/32.css')) . '?0");
 ', 'all'),
         ),
       ),
@@ -422,40 +433,40 @@ class CssCollectionRendererUnitTest extends UnitTestCase {
         ),
         array(
           0 => $create_style_element('
-@import url("' . file_create_url('public://css/1.css') . '?0");
-@import url("' . file_create_url('public://css/2.css') . '?0");
-@import url("' . file_create_url('public://css/3.css') . '?0");
-@import url("' . file_create_url('public://css/4.css') . '?0");
-@import url("' . file_create_url('public://css/5.css') . '?0");
-@import url("' . file_create_url('public://css/6.css') . '?0");
-@import url("' . file_create_url('public://css/7.css') . '?0");
-@import url("' . file_create_url('public://css/8.css') . '?0");
-@import url("' . file_create_url('public://css/9.css') . '?0");
-@import url("' . file_create_url('public://css/10.css') . '?0");
-@import url("' . file_create_url('public://css/11.css') . '?0");
-@import url("' . file_create_url('public://css/12.css') . '?0");
-@import url("' . file_create_url('public://css/13.css') . '?0");
-@import url("' . file_create_url('public://css/14.css') . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/1.css')) . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/2.css')) . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/3.css')) . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/4.css')) . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/5.css')) . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/6.css')) . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/7.css')) . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/8.css')) . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/9.css')) . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/10.css')) . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/11.css')) . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/12.css')) . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/13.css')) . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/14.css')) . '?0");
 ', 'all'),
-          1 => $create_link_element(file_create_url('public://css/15.css') . '?0'),
+          1 => $create_link_element(file_url_transform_relative(file_create_url('public://css/15.css')) . '?0'),
           2 => $create_style_element('
-@import url("' . file_create_url('public://css/16.css') . '?0");
-@import url("' . file_create_url('public://css/17.css') . '?0");
-@import url("' . file_create_url('public://css/18.css') . '?0");
-@import url("' . file_create_url('public://css/19.css') . '?0");
-@import url("' . file_create_url('public://css/20.css') . '?0");
-@import url("' . file_create_url('public://css/21.css') . '?0");
-@import url("' . file_create_url('public://css/22.css') . '?0");
-@import url("' . file_create_url('public://css/23.css') . '?0");
-@import url("' . file_create_url('public://css/24.css') . '?0");
-@import url("' . file_create_url('public://css/25.css') . '?0");
-@import url("' . file_create_url('public://css/26.css') . '?0");
-@import url("' . file_create_url('public://css/27.css') . '?0");
-@import url("' . file_create_url('public://css/28.css') . '?0");
-@import url("' . file_create_url('public://css/29.css') . '?0");
-@import url("' . file_create_url('public://css/30.css') . '?0");
-@import url("' . file_create_url('public://css/31.css') . '?0");
-@import url("' . file_create_url('public://css/32.css') . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/16.css')) . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/17.css')) . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/18.css')) . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/19.css')) . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/20.css')) . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/21.css')) . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/22.css')) . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/23.css')) . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/24.css')) . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/25.css')) . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/26.css')) . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/27.css')) . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/28.css')) . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/29.css')) . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/30.css')) . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/31.css')) . '?0");
+@import url("' . file_url_transform_relative(file_create_url('public://css/32.css')) . '?0");
 ', 'all'),
         ),
       ),
